Stan Math Library: stan/math/prim/mat/fun/LDLT_factor.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
LDLT_factor.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <boost/shared_ptr.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/prim/scal/fun/is_nan.hpp>`

Go to the source code of this file.

## Classes
class | stan::math::LDLT_factor< T, R, C >
class | stan::math::LDLT_factor< T, R, C >
| LDLT_factor is a thin wrapper on Eigen::LDLT to allow for reusing factorizations and efficient autodiff of things like log determinants and solutions to linear systems. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.